"""Common types used in the models of the pricehub app."""

from typing import Literal, Union
import datetime
import pandas as pd


import arrow

SupportedBroker = Literal[
    "binance_spot", "binance_futures", "bybit_spot", "bybit_linear", "bybit_inverse", "coinbase_spot", "okx_spot"
]
Timestamp = Union[int, float, str, arrow.Arrow, pd.Timestamp, datetime.datetime, datetime.date]
Interval = Literal["1s", "1m", "3m", "5m", "15m", "30m", "1h", "2h", "4h", "6h", "8h", "12h", "1d", "3d", "1w", "1M"]
